==> spip_3.2.11.orig.tar.xz: plugins-dist/dump/lang/dump_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucune_donnee' => 'هيچ داده‌اي در پرونده نيست.',
	'avis_probleme_ecriture_fichier' => 'مشكل نوشتن پرونده‌ي 
 @fichier@',

	// B
	'bouton_restaurer_base' => 'باز سازى پايگاه',

	// C
	'confirmer_ecraser_base' => 'بله، مي‌خواهم پايگاه داده‌هايم را با اين بك‌آپ بازنويسي كنم',
	'confirmer_ecraser_tables_selection' => 'بله، مي‌خواهم جدول منتخب را با اين بك‌آپ بازنويسي كنم',

	// D
	'details_sauvegarde' => 'حزئيات بك‌آپ :',

	// E
	'erreur_aucune_donnee_restauree' => 'هيچ داده‌اي ذخيره نشده',
	'erreur_connect_dump' => 'سروري به نام 
« @dump@ »
 پيشتر وجود داشته. دوباره آن را  نام‌گذاري كنيد',
	'erreur_creation_base_sqlite' => 'ايجاد يك پايگاه اس.كيو.لايت براي اين بك‌آپ ممكن نيست',
	'erreur_nom_fichier' => 'اين نام پرونده مجاز نيست',
	'erreur_restaurer_verifiez' => 'براي ذخيره شدن خطا را برطرف كنيد.',
	'erreur_sauvegarde_deja_en_cours' => 'شما يك بك‌آپ در جريان داريد',
	'erreur_sqlite_indisponible' => 'گرفتن بك‌آپ اس.كيو.لايت روي ميزبان ارايه‌‌دهنده‌ي شما ممكن نيست',
	'erreur_table_absente' => '@table@ فقدان جدول ',
	'erreur_table_donnees_manquantes' => '@table@ جدول ،
نبود داده‌ها',
	'erreur_taille_sauvegarde' => 'به نظر مي‌رسد بك‌اپ موفق نبوده، پرونده‌ي
@fichier@
  خالي است يا موجود نيست',

	// I
	'info_aucune_sauvegarde_trouvee' => 'هيچ ذخيره‌اي يافت نشد',
	'info_restauration_finie' => 'تمام شد. بك‌آپ
@archive@
روي سايت شما ذخيره شد. شما مي‌توانيد',
	'info_restauration_sauvegarde' => 'استفرار مجدد حفظ @archive@',
	'info_sauvegarde' => 'ذخيره',
	'info_sauvegarde_reussi_02' => 'ذخيره پايگاه در  @archive@انجام شد. شما ميتوانيد',
	'info_sauvegarde_reussi_03' => 'به بخش اداره برگرديد',
	'info_sauvegarde_reussi_04' => '.سايتتان',
	'info_selection_sauvegarde' => '@fichier@ را انتخاب كرده‌ايد.  شما بازسازي ذخيره‌ اين عمكرد بازيافتني نيست. ',

	// L
	'label_nom_fichier_restaurer' => 'يا نام پرونده را براي بازسازي مشخص كنيد',
	'label_nom_fichier_sauvegarde' => 'نام پرونده‌ براي ذخيره‌سازي آن ',
	'label_selectionnez_fichier' => 'يك پرونده را از فهرست انتخاب كنيد',

	// N
	'nb_donnees' => '@nb@ ثبت‌ شده‌',

	// R
	'restauration_en_cours' => 'بازسازي در جريان است',

	// S
	'sauvegarde_en_cours' => 'ذخيره‌سازي در جريان است',
	'sauvegardes_existantes' => 'ذخيره‌هاي موجود',
	'selectionnez_table_a_restaurer' => 'جدول‌ها را براي بازسازي انتخاب كنيد',

	// T
	'texte_admin_tech_01' => 'اين گزينش بشما امكان ذخيره محتوى داده پى ها را در فايلى كه در فهرست زير آمده است ميدهد@dossier@.فراموش نكنيد كه تمامى محتوى رپرتوار  @img@ را كه شامل تصاوير و اسناد استفاده شده و بخشهاست را دوباره پس بگيريد.',
	'texte_admin_tech_02' => 'توجه! اين بك‌ آپ (ذخيره) فقط بايد  با همان نسخه‌ي اسپيپي كه ساخته شده بازسازي شود. به خصوص نبايد پايگاه‌داده‌ها را به منظور نصب دوباره‌ي بك‌آپ (ذخيره) پس از بروز رساني خالي كرد... براى اطلاع بيشتر به <a href="@spipnet@">la اسناد اسپيپ</a> رجوع كنيد.',
	'texte_restaurer_base' => 'محتوى ذخيره پايگاه را بازسازى كنيد',
	'texte_restaurer_sauvegarde' => 'اين گزينش بشما امكان بازسازى ذخيره از پايگاه را كه پيشتر گرفته‌ايد، ميدهد. دراينصورت بايد فايل محتوى ذخيره را در اين رپرتوار قرار دهيد.@dossier@.
با احتياط عمل كنيد چون هرگونه دستكارى يا از بين رفتن غيرقابل برگشت ميباشد.</b>',
	'texte_sauvegarde' => 'محتوى پايگاه را ذخيره كنيد',
	'texte_sauvegarde_base' => 'پايگاه را ذخيره كنيد',
	'tout_restaurer' => 'بازسازي تمام جدول‌ها',
	'tout_sauvegarder' => 'ذخيره‌سازي تمام جدول‌ها',

	// U
	'une_donnee' => '1 ثبت شده'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// A
	'aucune_donnee' => 'هيچ داده‌اي در پرونده نيست.',
	'avis_probleme_ecriture_fichier' => 'مشكل نوشتن پرونده‌ي 
 @fichier@',

	// B
	'bouton_restaurer_base' => 'باز سازى پايگاه',

	// C
	'confirmer_ecraser_base' => 'بله، مي‌خواهم پايگاه داده‌هايم را با اين بك‌آپ بازنويسي كنم',
	'confirmer_ecraser_tables_selection' => 'بله، مي‌خواهم جدول منتخب را با اين بك‌آپ بازنويسي كنم',

	// D
	'details_sauvegarde' => 'حزئيات بك‌آپ :',

	// E
	'erreur_aucune_donnee_restauree' => 'هيچ داده‌اي ذخيره نشده',
	'erreur_connect_dump' => 'سروري به نام 
« @dump@ »
 پيشتر وجود داشته. دوباره آن را  نام‌گذاري كنيد',
	'erreur_creation_base_sqlite' => 'ايجاد يك پايگاه اس.كيو.لايت براي اين بك‌آپ ممكن نيست',
	'erreur_nom_fichier' => 'اين نام پرونده مجاز نيست',
	'erreur_restaurer_verifiez' => 'براي ذخيره شدن خطا را برطرف كنيد.',
	'erreur_sauvegarde_deja_en_cours' => 'شما يك بك‌آپ در جريان داريد',
	'erreur_sqlite_indisponible' => 'گرفتن بك‌آپ اس.كيو.لايت روي ميزبان ارايه‌‌دهنده‌ي شما ممكن نيست',
	'erreur_table_absente' => '@table@ فقدان جدول ',
	'erreur_table_donnees_manquantes' => '@table@ جدول ،
نبود داده‌ها',
	'erreur_taille_sauvegarde' => 'به نظر مي‌رسد بك‌اپ موفق نبوده، پرونده‌ي
@fichier@
  خالي است يا موجود نيست',

	// I
	'info_aucune_sauvegarde_trouvee' => 'هيچ ذخيره‌اي يافت نشد',
	'info_restauration_finie' => 'تمام شد. بك‌آپ
@archive@
روي سايت شما ذخيره شد. شما مي‌توانيد',
	'info_restauration_sauvegarde' => 'استفرار مجدد حفظ @archive@',
	'info_sauvegarde' => 'ذخيره',
	'info_sauvegarde_reussi_02' => 'ذخيره پايگاه در  @archive@انجام شد. شما ميتوانيد',
	'info_sauvegarde_reussi_03' => 'به بخش اداره برگرديد',
	'info_sauvegarde_reussi_04' => '.سايتتان',
	'info_selection_sauvegarde' => '@fichier@ را انتخاب كرده‌ايد.  شما بازسازي ذخيره‌ اين عمكرد بازيافتني نيست. ',

	// L
	'label_nom_fichier_restaurer' => 'يا نام پرونده را براي بازسازي مشخص كنيد',
	'label_nom_fichier_sauvegarde' => 'نام پرونده‌ براي ذخيره‌سازي آن ',
	'label_selectionnez_fichier' => 'يك پرونده را از فهرست انتخاب كنيد',

	// N
	'nb_donnees' => '@nb@ ثبت‌ شده‌',

	// R
	'restauration_en_cours' => 'بازسازي در جريان است',

	// S
	'sauvegarde_en_cours' => 'ذخيره‌سازي در جريان است',
	'sauvegardes_existantes' => 'ذخيره‌هاي موجود',
	'selectionnez_table_a_restaurer' => 'جدول‌ها را براي بازسازي انتخاب كنيد',

	// T
	'texte_admin_tech_01' => 'اين گزينش بشما امكان ذخيره محتوى داده پى ها را در فايلى كه در فهرست زير آمده است ميدهد@dossier@.فراموش نكنيد كه تمامى محتوى رپرتوار  @img@ را كه شامل تصاوير و اسناد استفاده شده و بخشهاست را دوباره پس بگيريد.',
	'texte_admin_tech_02' => 'توجه! اين بك‌ آپ (ذخيره) فقط بايد  با همان نسخه‌ي اسپيپي كه ساخته شده بازسازي شود. به خصوص نبايد پايگاه‌داده‌ها را به منظور نصب دوباره‌ي بك‌آپ (ذخيره) پس از بروز رساني خالي كرد... براى اطلاع بيشتر به <a href="@spipnet@">la اسناد اسپيپ</a> رجوع كنيد.',
	'texte_restaurer_base' => 'محتوى ذخيره پايگاه را بازسازى كنيد',
	'texte_restaurer_sauvegarde' => 'اين گزينش بشما امكان بازسازى ذخيره از پايگاه را كه پيشتر گرفته‌ايد، ميدهد. دراينصورت بايد فايل محتوى ذخيره را در اين رپرتوار قرار دهيد.@dossier@.
با احتياط عمل كنيد چون هرگونه دستكارى يا از بين رفتن غيرقابل برگشت ميباشد.</b>',
	'texte_sauvegarde' => 'محتوى پايگاه را ذخيره كنيد',
	'texte_sauvegarde_base' => 'پايگاه را ذخيره كنيد',
	'tout_restaurer' => 'بازسازي تمام جدول‌ها',
	'tout_sauvegarder' => 'ذخيره‌سازي تمام جدول‌ها',

	// U
	'une_donnee' => '1 ثبت شده',
];
